@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
+
 module Rouge
   module Lexers
     class AppleScript < RegexLexer
+      title "AppleScript"
       desc "The AppleScript scripting language by Apple Inc. (http://developer.apple.com/applescript/)"
 
       tag 'applescript'
