@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 module Rouge
   module Lexers
@@ -8,7 +9,7 @@ module Rouge
       tag 'common_lisp'
       aliases 'cl', 'common-lisp', 'elisp', 'emacs-lisp'
 
-      filenames '*.cl', '*.lisp', '*.el' # used for Elisp too
+      filenames '*.cl', '*.lisp', '*.asd', '*.el' # used for Elisp too
       mimetypes 'text/x-common-lisp'
 
       # 638 functions
@@ -153,7 +154,7 @@ module Rouge
         declaim defclass defconstant defgeneric define-compiler-macro
         define-condition define-method-combination define-modify-macro
         define-setf-expander define-symbol-macro defmacro defmethod
-        defpackage defparameter defsetf defstruct deftype defun defvar
+        defpackage defparameter defsetf defstruct defsystem deftype defun defvar
         destructuring-bind do do* do-all-symbols do-external-symbols
         dolist do-symbols dotimes ecase etypecase formatter
         handler-bind handler-case ignore-errors incf in-package
