@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*- #
+# frozen_string_literal: true
 
 module Rouge
   module Lexers
@@ -9,9 +10,9 @@ module Rouge
       aliases 'pp'
       filenames '*.pp'
 
-      def self.analyze_text(text)
-        return 1 if text.shebang? 'puppet-apply'
-        return 1 if text.shebang? 'puppet'
+      def self.detect?(text)
+        return true if text.shebang? 'puppet-apply'
+        return true if text.shebang? 'puppet'
       end
 
       def self.keywords
@@ -67,7 +68,7 @@ module Rouge
         rule /(in|and|or)\b/, Operator::Word
         rule /[=!<>]=/, Operator
         rule /[=!]~/, Operator, :regex_allowed
-        rule %r([<>!+*/-]), Operator
+        rule %r([=<>!+*/-]), Operator
 
         rule /(class|include)(\s*)(#{qualname})/ do
           groups Keyword, Text, Name::Class
